/* -*- Mode: C; tab-width: 2; indent-tabs-mode: t; c-basic-offset: 2 -*- */
/* vi: set ts=2 sw=2: */
/* error.h

   GJITEN : A GTK+/GNOME BASED JAPANESE DICTIONARY
  
   Copyright (C) 1999 - 2005 Botond Botyanszki <boti@rocketmail.com>

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published  by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
 */

#ifndef __ERROR_H__
#define __ERROR_H__

#ifdef DEBUG_GJITEN
#define GJITEN_DEBUG(...) fprintf(stderr, __VA_ARGS__)
#else 
#define GJITEN_DEBUG(...)
#endif

int gjiten_print_error(const char *fmt, ... );
void gjiten_print_error_and_wait(const char *fmt, ... );
gboolean gjiten_print_question(const char *fmt, ... );
void gjiten_add_errormsg(gchar *msg);
void gjiten_flush_errors();
void gjiten_abort_with_msg(const char *fmt, ... );

#endif
